## ${finding_name}

<table style='Table Grid' column_widths='1in, 1in, 3in, 1in, 1.2in'>
<para before=6pt spacing=1.15 after=6pt align=center>
|<cell color='#000000'>Risk Rating</cell>|<cell color='#000000'>Overall Score</cell>|<cell color='#000000'>CVSS Vector</cell>|<cell color='#000000'>CWE ID</cell>|<cell color='#000000'>OWASP Top 10</cell>|
|---|---|---|---|---|
|<cell color='${color}'>${severity}</cell>|${score_print}|${vector}|||
</para>
</table>

**Affected Modules**

<table style='Table Grid' column_widths='6in, 1.2in'>
|<cell color='#000000'>Filename</cell>|<cell color='#000000'>Line</cell>|
|---|---|
| | |
</table>

**Observations**

**Screenshots**

<align center>
<img width=5in border_width=1.5pt>![](screencaps/test-1.png "TODO: caption 1")</img>

<img width=5in border_width=1.5pt>![](screencaps/test-2.png "TODO: caption 2")</img>
</align>

**Implications**

**Recommendations**

**Reference**

**Status**

Open

<pgbr>
